=======
History
=======

v2.0.0 [25 Oct 2021]
--------------------

Fixed
-----

* Bayesian evidence computed correctly in polychord now (with tests)
* polychord now saves into the correct directory.


v1.0.0 [18 May 2021]
----------------------

Changed
~~~~~~~

* Nicer YAML interface
* Better data loading interface


0.0.1 (2019-04-25)
------------------

* First release on PyPI.
